#! /bin/sh
#------------------------------------------------------------
#script to set/unset VZ veth interface according vz config
#script is called via /usr/sbin/vznetcfg (up) and 
#/etc/vz/conf/vps.umount (down)
#one parameter  $1
# $1=init $2 veth $3 vzhostif	 :	set the interface up
# $1=remove  			:  set interface down
#------------------------------------------------------------
#checking if VZ config is existing
CTCONFIGFILE=/etc/vz/conf/$VEID.conf
if [ ! -f $CTCONFIGFILE ] ; then
  echo "Config file $CTCONFIGFILE missing!" ;
  exit 1 ;
  fi

#loading VZ config
. $CTCONFIGFILE
#------------------------------------------------------------
case "$1" in
  "init"	)
    DSRVZ=$VE_PRIVATE
    ;;
  "remove"	)
    DSRVZ=$VE_ROOT
    ;;
  *		)
    echo "ACTION request '$1' is unexpected!" ;
    exit 1 ;
    ;;
  esac

#defining container area
ROOT=$DSRVZ

CTIFNAME="";
VZHOSTIF="";
BRIDGEDEV="br0"

for ONENETIF in $(echo $NETIF | tr -s ';' ' '); do
  NETIF_OPTIONS=`echo $ONENETIF | sed 's/,/\n/g'`
  for str in $NETIF_OPTIONS;
    do 
    # getting 'ifname' parameter value
    if  [ `echo $str | grep -o '^ifname='` ] ; then
      # remove the parameter name from the string (along with '=')
      CTIFNAME=${str#*=};
      fi
    # getting 'host_ifname' parameter value
    if  [ `echo $str | grep -o '^host_ifname='` ] ; then
      # remove the parameter name from the string (along with '=')
      VZHOSTIF=${str#*=};
      fi
    # getting 'Bridge' parameter value
    if  [ `echo $str | grep -o '^bridge='` ] ; then
      # remove the parameter name from the string (along with '=')
      BRIDGEDEV=${str#*=};
      fi
    done
  if [ -n "$CTIFNAME" -a -n "$VZHOSTIF" -a -n "$BRIDGEDEV" ] ; then
    #adding removing VETH to bridge.
    case "$1" in
      "init"	)
        if [ "$3" = "$VZHOSTIF" ] ; then
          echo "Adding interface $VZHOSTIF to bridge $BRIDGEDEV."
          brctl addif $BRIDGEDEV $VZHOSTIF
	  fi
        ;;
      "remove"	)
        ;;
      esac
    #updating routing
    for cfg in $ROOT/etc/sysconfig/network-scripts/ifcfg-$CTIFNAME
      do
      ADDR=`grep IPADDR $cfg | cut -d'=' -f2`
      if [ -n "$ADDR" ] ; then
        case "$1" in
          "init"    )
    	     if [ "$3" = "$VZHOSTIF" ] ; then
               echo "Adding route to $ADDR to the bridge $BRIDGEDEV."
	       /sbin/route add $ADDR dev $BRIDGEDEV
	       fi
	     ;;
          "remove"    )
            echo "Removing route to $ADDR from the bridge $BRIDGEDEV."
	    /sbin/route del $ADDR dev $BRIDGEDEV
	    ;;
          esac
	fi
      done
    fi
  done
exit 0;
